dumb-udev
===========================

<a href='https://ko-fi.com/I2I21F8E1' target='_blank'><img height='26' style='border:0px;height:26px;' src='https://cdn.ko-fi.com/cdn/kofi1.png?v=2' border='0' alt='Buy Me a Coffee at ko-fi.com' /></a>

---

This python module is a minimal input broadcaster designed to be run inside containers as a replacement to udevd.
This is not a full udevd replacement.

---
